==> jackrabbit-oak-1.22.23-src.zip: jackrabbit-oak-1.22.23/oak-core/src/test/java/org/apache/jackrabbit/oak/security/authentication/AuthenticationConfigurationImplOSGiTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.security.authentication;

import com.google.common.collect.Maps;
import org.apache.jackrabbit.oak.AbstractSecurityTest;
import org.apache.jackrabbit.oak.osgi.OsgiUtil;
import org.apache.jackrabbit.oak.spi.security.ConfigurationParameters;
import org.apache.sling.testing.mock.osgi.junit.OsgiContext;
import org.junit.Rule;
import org.junit.Test;
import org.osgi.framework.Constants;

import javax.jcr.SimpleCredentials;

import static org.apache.jackrabbit.oak.spi.security.authentication.AuthenticationConfiguration.PARAM_APP_NAME;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class AuthenticationConfigurationImplOSGiTest extends AbstractSecurityTest {

    @Rule
    public final OsgiContext context = new OsgiContext();

    private final AuthenticationConfigurationImpl authenticationConfiguration = new AuthenticationConfigurationImpl();

    private SimpleCredentials sc;

    @Override
    public void before() throws Exception {
        super.before();

        authenticationConfiguration.setSecurityProvider(getSecurityProvider());
    }

    @Test
    public void testGetParameters() {
        context.registerInjectActivateService(authenticationConfiguration, ConfigurationParameters.of(PARAM_APP_NAME, "name"));

        ConfigurationParameters expected = ConfigurationParameters.of(
                PARAM_APP_NAME, "name",
                Constants.SERVICE_PID, authenticationConfiguration.getClass().getName());
        assertTrue(Maps.difference(expected, authenticationConfiguration.getParameters()).areEqual());
    }
}

==> jackrabbit-oak-1.70.0-src.zip: jackrabbit-oak-1.70.0/oak-core/src/test/java/org/apache/jackrabbit/oak/security/authentication/AuthenticationConfigurationImplOSGiTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.security.authentication;

import org.apache.jackrabbit.guava.common.collect.Maps;
import org.apache.jackrabbit.oak.AbstractSecurityTest;
import org.apache.jackrabbit.oak.osgi.OsgiUtil;
import org.apache.jackrabbit.oak.spi.security.ConfigurationParameters;
import org.apache.sling.testing.mock.osgi.junit.OsgiContext;
import org.junit.Rule;
import org.junit.Test;
import org.osgi.framework.Constants;

import javax.jcr.SimpleCredentials;

import static org.apache.jackrabbit.oak.spi.security.authentication.AuthenticationConfiguration.PARAM_APP_NAME;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class AuthenticationConfigurationImplOSGiTest extends AbstractSecurityTest {

    @Rule
    public final OsgiContext context = new OsgiContext();

    private final AuthenticationConfigurationImpl authenticationConfiguration = new AuthenticationConfigurationImpl();

    private SimpleCredentials sc;

    @Override
    public void before() throws Exception {
        super.before();

        authenticationConfiguration.setSecurityProvider(getSecurityProvider());
    }

    @Test
    public void testGetParameters() {
        context.registerInjectActivateService(authenticationConfiguration, ConfigurationParameters.of(PARAM_APP_NAME, "name"));

        ConfigurationParameters expected = ConfigurationParameters.of(
                PARAM_APP_NAME, "name",
                Constants.SERVICE_PID, authenticationConfiguration.getClass().getName());
        assertTrue(Maps.difference(expected, authenticationConfiguration.getParameters()).areEqual());
    }
}
